# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/ranking_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import ranking_event_pb2 as eolymp_dot_community_dot_ranking__event__pb2
from eolymp.community import ranking_point_pb2 as eolymp_dot_community_dot_ranking__point__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/community/ranking_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a$eolymp/community/ranking_event.proto\x1a$eolymp/community/ranking_point.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"H\n\x17\x43reateRankingEventInput\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.eolymp.community.RankingEvent\",\n\x18\x43reateRankingEventOutput\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\"\xd5\x01\n\x17UpdateRankingEventInput\x12>\n\x05patch\x18\x01 \x03(\x0e\x32/.eolymp.community.UpdateRankingEventInput.Patch\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12-\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.eolymp.community.RankingEvent\"9\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\r\n\tTIMESTAMP\x10\x02\x12\x0e\n\nCONTEST_ID\x10\x03\"\x1a\n\x18UpdateRankingEventOutput\"+\n\x17\x44\x65leteRankingEventInput\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteRankingEventOutput\"-\n\x19\x44\x65scribeRankingEventInput\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\"K\n\x1a\x44\x65scribeRankingEventOutput\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.eolymp.community.RankingEvent\"\xe1\x03\n\x16ListRankingEventsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12@\n\x07\x66ilters\x18( \x01(\x0b\x32/.eolymp.community.ListRankingEventsInput.Filter\x12?\n\x04sort\x18\x32 \x01(\x0e\x32\x31.eolymp.community.ListRankingEventsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xd4\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\ttimestamp\x18\x03 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x32\n\ncontest_id\x18\x64 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"#\n\x08Sortable\x12\r\n\tTIMESTAMP\x10\x00\x12\x08\n\x04NAME\x10\x01\"W\n\x17ListRankingEventsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.eolymp.community.RankingEvent\"m\n\x17UpdateRankingPointInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12-\n\x05point\x18\n \x01(\x0b\x32\x1e.eolymp.community.RankingPoint\"\x1a\n\x18UpdateRankingPointOutput\"m\n\x17\x44\x65leteRankingPointInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12-\n\x05point\x18\n \x01(\x0b\x32\x1e.eolymp.community.RankingPoint\"\x1a\n\x18\x44\x65leteRankingPointOutput\"@\n\x19\x44\x65scribeRankingPointInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\"K\n\x1a\x44\x65scribeRankingPointOutput\x12-\n\x05point\x18\x01 \x01(\x0b\x32\x1e.eolymp.community.RankingPoint\"\xfb\x02\n\x16ListRankingPointsInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12@\n\x07\x66ilters\x18( \x01(\x0b\x32/.eolymp.community.ListRankingPointsInput.Filter\x12?\n\x04sort\x18\x32 \x01(\x0e\x32\x31.eolymp.community.ListRankingPointsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08\x65vent_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x19\n\x08Sortable\x12\r\n\tTIMESTAMP\x10\x00\"W\n\x17ListRankingPointsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.eolymp.community.RankingPoint2\xef\r\n\x0eRankingService\x12\xb1\x01\n\x12\x43reateRankingEvent\x12).eolymp.community.CreateRankingEventInput\x1a*.eolymp.community.CreateRankingEventOutput\"D\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\"\x0f/ranking-events\x12\xbc\x01\n\x12UpdateRankingEvent\x12).eolymp.community.UpdateRankingEventInput\x1a*.eolymp.community.UpdateRankingEventOutput\"O\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\"\x1a/ranking-events/{event_id}\x12\xbc\x01\n\x12\x44\x65leteRankingEvent\x12).eolymp.community.DeleteRankingEventInput\x1a*.eolymp.community.DeleteRankingEventOutput\"O\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c*\x1a/ranking-events/{event_id}\x12\xc1\x01\n\x14\x44\x65scribeRankingEvent\x12+.eolymp.community.DescribeRankingEventInput\x1a,.eolymp.community.DescribeRankingEventOutput\"N\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\x12\x1a/ranking-events/{event_id}\x12\xad\x01\n\x11ListRankingEvents\x12(.eolymp.community.ListRankingEventsInput\x1a).eolymp.community.ListRankingEventsOutput\"C\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/ranking-events\x12\xcf\x01\n\x12UpdateRankingPoint\x12).eolymp.community.UpdateRankingPointInput\x1a*.eolymp.community.UpdateRankingPointOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/\x1a-/ranking-series/{member_id}/points/{event_id}\x12\xcf\x01\n\x12\x44\x65leteRankingPoint\x12).eolymp.community.DeleteRankingPointInput\x1a*.eolymp.community.DeleteRankingPointOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/*-/ranking-series/{member_id}/points/{event_id}\x12\xd5\x01\n\x14\x44\x65scribeRankingPoint\x12+.eolymp.community.DescribeRankingPointInput\x1a,.eolymp.community.DescribeRankingPointOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/\x12-/ranking-series/{member_id}/points/{event_id}\x12\xba\x01\n\x11ListRankingPoints\x12(.eolymp.community.ListRankingPointsInput\x1a).eolymp.community.ListRankingPointsOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\x12\x1b/ranking-series/{member_id}B5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.ranking_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _RANKINGSERVICE.methods_by_name['CreateRankingEvent']._options = None
  _RANKINGSERVICE.methods_by_name['CreateRankingEvent']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\021\"\017/ranking-events'
  _RANKINGSERVICE.methods_by_name['UpdateRankingEvent']._options = None
  _RANKINGSERVICE.methods_by_name['UpdateRankingEvent']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\"\032/ranking-events/{event_id}'
  _RANKINGSERVICE.methods_by_name['DeleteRankingEvent']._options = None
  _RANKINGSERVICE.methods_by_name['DeleteRankingEvent']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034*\032/ranking-events/{event_id}'
  _RANKINGSERVICE.methods_by_name['DescribeRankingEvent']._options = None
  _RANKINGSERVICE.methods_by_name['DescribeRankingEvent']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\022\032/ranking-events/{event_id}'
  _RANKINGSERVICE.methods_by_name['ListRankingEvents']._options = None
  _RANKINGSERVICE.methods_by_name['ListRankingEvents']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\021\022\017/ranking-events'
  _RANKINGSERVICE.methods_by_name['UpdateRankingPoint']._options = None
  _RANKINGSERVICE.methods_by_name['UpdateRankingPoint']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/\032-/ranking-series/{member_id}/points/{event_id}'
  _RANKINGSERVICE.methods_by_name['DeleteRankingPoint']._options = None
  _RANKINGSERVICE.methods_by_name['DeleteRankingPoint']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/*-/ranking-series/{member_id}/points/{event_id}'
  _RANKINGSERVICE.methods_by_name['DescribeRankingPoint']._options = None
  _RANKINGSERVICE.methods_by_name['DescribeRankingPoint']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/\022-/ranking-series/{member_id}/points/{event_id}'
  _RANKINGSERVICE.methods_by_name['ListRankingPoints']._options = None
  _RANKINGSERVICE.methods_by_name['ListRankingPoints']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\022\033/ranking-series/{member_id}'
  _CREATERANKINGEVENTINPUT._serialized_start=304
  _CREATERANKINGEVENTINPUT._serialized_end=376
  _CREATERANKINGEVENTOUTPUT._serialized_start=378
  _CREATERANKINGEVENTOUTPUT._serialized_end=422
  _UPDATERANKINGEVENTINPUT._serialized_start=425
  _UPDATERANKINGEVENTINPUT._serialized_end=638
  _UPDATERANKINGEVENTINPUT_PATCH._serialized_start=581
  _UPDATERANKINGEVENTINPUT_PATCH._serialized_end=638
  _UPDATERANKINGEVENTOUTPUT._serialized_start=640
  _UPDATERANKINGEVENTOUTPUT._serialized_end=666
  _DELETERANKINGEVENTINPUT._serialized_start=668
  _DELETERANKINGEVENTINPUT._serialized_end=711
  _DELETERANKINGEVENTOUTPUT._serialized_start=713
  _DELETERANKINGEVENTOUTPUT._serialized_end=739
  _DESCRIBERANKINGEVENTINPUT._serialized_start=741
  _DESCRIBERANKINGEVENTINPUT._serialized_end=786
  _DESCRIBERANKINGEVENTOUTPUT._serialized_start=788
  _DESCRIBERANKINGEVENTOUTPUT._serialized_end=863
  _LISTRANKINGEVENTSINPUT._serialized_start=866
  _LISTRANKINGEVENTSINPUT._serialized_end=1347
  _LISTRANKINGEVENTSINPUT_FILTER._serialized_start=1098
  _LISTRANKINGEVENTSINPUT_FILTER._serialized_end=1310
  _LISTRANKINGEVENTSINPUT_SORTABLE._serialized_start=1312
  _LISTRANKINGEVENTSINPUT_SORTABLE._serialized_end=1347
  _LISTRANKINGEVENTSOUTPUT._serialized_start=1349
  _LISTRANKINGEVENTSOUTPUT._serialized_end=1436
  _UPDATERANKINGPOINTINPUT._serialized_start=1438
  _UPDATERANKINGPOINTINPUT._serialized_end=1547
  _UPDATERANKINGPOINTOUTPUT._serialized_start=1549
  _UPDATERANKINGPOINTOUTPUT._serialized_end=1575
  _DELETERANKINGPOINTINPUT._serialized_start=1577
  _DELETERANKINGPOINTINPUT._serialized_end=1686
  _DELETERANKINGPOINTOUTPUT._serialized_start=1688
  _DELETERANKINGPOINTOUTPUT._serialized_end=1714
  _DESCRIBERANKINGPOINTINPUT._serialized_start=1716
  _DESCRIBERANKINGPOINTINPUT._serialized_end=1780
  _DESCRIBERANKINGPOINTOUTPUT._serialized_start=1782
  _DESCRIBERANKINGPOINTOUTPUT._serialized_end=1857
  _LISTRANKINGPOINTSINPUT._serialized_start=1860
  _LISTRANKINGPOINTSINPUT._serialized_end=2239
  _LISTRANKINGPOINTSINPUT_FILTER._serialized_start=2110
  _LISTRANKINGPOINTSINPUT_FILTER._serialized_end=2212
  _LISTRANKINGPOINTSINPUT_SORTABLE._serialized_start=1312
  _LISTRANKINGPOINTSINPUT_SORTABLE._serialized_end=1337
  _LISTRANKINGPOINTSOUTPUT._serialized_start=2241
  _LISTRANKINGPOINTSOUTPUT._serialized_end=2328
  _RANKINGSERVICE._serialized_start=2331
  _RANKINGSERVICE._serialized_end=4106
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import ranking_event_pb2 as _ranking_event_pb2
from eolymp.community import ranking_point_pb2 as _ranking_point_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateRankingEventInput(_message.Message):
    __slots__ = ["event"]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: _ranking_event_pb2.RankingEvent
    def __init__(self, event: _Optional[_Union[_ranking_event_pb2.RankingEvent, _Mapping]] = ...) -> None: ...

class CreateRankingEventOutput(_message.Message):
    __slots__ = ["event_id"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    def __init__(self, event_id: _Optional[str] = ...) -> None: ...

class DeleteRankingEventInput(_message.Message):
    __slots__ = ["event_id"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    def __init__(self, event_id: _Optional[str] = ...) -> None: ...

class DeleteRankingEventOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteRankingPointInput(_message.Message):
    __slots__ = ["event_id", "member_id", "point"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    POINT_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    member_id: str
    point: _ranking_point_pb2.RankingPoint
    def __init__(self, member_id: _Optional[str] = ..., event_id: _Optional[str] = ..., point: _Optional[_Union[_ranking_point_pb2.RankingPoint, _Mapping]] = ...) -> None: ...

class DeleteRankingPointOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeRankingEventInput(_message.Message):
    __slots__ = ["event_id"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    def __init__(self, event_id: _Optional[str] = ...) -> None: ...

class DescribeRankingEventOutput(_message.Message):
    __slots__ = ["event"]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: _ranking_event_pb2.RankingEvent
    def __init__(self, event: _Optional[_Union[_ranking_event_pb2.RankingEvent, _Mapping]] = ...) -> None: ...

class DescribeRankingPointInput(_message.Message):
    __slots__ = ["event_id", "member_id"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    member_id: str
    def __init__(self, member_id: _Optional[str] = ..., event_id: _Optional[str] = ...) -> None: ...

class DescribeRankingPointOutput(_message.Message):
    __slots__ = ["point"]
    POINT_FIELD_NUMBER: _ClassVar[int]
    point: _ranking_point_pb2.RankingPoint
    def __init__(self, point: _Optional[_Union[_ranking_point_pb2.RankingPoint, _Mapping]] = ...) -> None: ...

class ListRankingEventsInput(_message.Message):
    __slots__ = ["filters", "offset", "order", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["contest_id", "id", "name", "timestamp"]
        CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        contest_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        timestamp: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., timestamp: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., contest_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    NAME: ListRankingEventsInput.Sortable
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP: ListRankingEventsInput.Sortable
    filters: ListRankingEventsInput.Filter
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListRankingEventsInput.Sortable
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListRankingEventsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListRankingEventsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListRankingEventsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_ranking_event_pb2.RankingEvent]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_ranking_event_pb2.RankingEvent, _Mapping]]] = ...) -> None: ...

class ListRankingPointsInput(_message.Message):
    __slots__ = ["filters", "member_id", "offset", "order", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["event_id", "id"]
        EVENT_ID_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        event_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., event_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP: ListRankingPointsInput.Sortable
    filters: ListRankingPointsInput.Filter
    member_id: str
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListRankingPointsInput.Sortable
    def __init__(self, member_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListRankingPointsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListRankingPointsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListRankingPointsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_ranking_point_pb2.RankingPoint]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_ranking_point_pb2.RankingPoint, _Mapping]]] = ...) -> None: ...

class UpdateRankingEventInput(_message.Message):
    __slots__ = ["event", "event_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateRankingEventInput.Patch
    CONTEST_ID: UpdateRankingEventInput.Patch
    EVENT_FIELD_NUMBER: _ClassVar[int]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME: UpdateRankingEventInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP: UpdateRankingEventInput.Patch
    event: _ranking_event_pb2.RankingEvent
    event_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateRankingEventInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateRankingEventInput.Patch, str]]] = ..., event_id: _Optional[str] = ..., event: _Optional[_Union[_ranking_event_pb2.RankingEvent, _Mapping]] = ...) -> None: ...

class UpdateRankingEventOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateRankingPointInput(_message.Message):
    __slots__ = ["event_id", "member_id", "point"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    POINT_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    member_id: str
    point: _ranking_point_pb2.RankingPoint
    def __init__(self, member_id: _Optional[str] = ..., event_id: _Optional[str] = ..., point: _Optional[_Union[_ranking_point_pb2.RankingPoint, _Mapping]] = ...) -> None: ...

class UpdateRankingPointOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/ranking_point.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/community/ranking_point.proto\x12\x10\x65olymp.community\"p\n\x0cRankingPoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\n \x01(\t\x12\x10\n\x08\x65vent_id\x18\x0b \x01(\t\x12\x0c\n\x04rank\x18\x14 \x01(\r\x12\x12\n\nrank_lower\x18\x15 \x01(\r\x12\r\n\x05score\x18\x1e \x01(\rB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.ranking_point_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _RANKINGPOINT._serialized_start=58
  _RANKINGPOINT._serialized_end=170
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RankingPoint(_message.Message):
    __slots__ = ["event_id", "id", "member_id", "rank", "rank_lower", "score"]
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    RANK_FIELD_NUMBER: _ClassVar[int]
    RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    id: str
    member_id: str
    rank: int
    rank_lower: int
    score: int
    def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., event_id: _Optional[str] = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., score: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class MemberServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateMember(self, request, **kwargs):
        path = "/members"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.CreateMemberOutput"),
            **kwargs,
        )

    def UpdateMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UpdateMemberOutput"),
            **kwargs,
        )

    def DeleteMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DeleteMemberOutput"),
            **kwargs,
        )

    def RestoreMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)+"/restore"

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.RestoreMemberOutput"),
            **kwargs,
        )

    def DescribeMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeMemberOutput"),
            **kwargs,
        )

    def ListMembers(self, request, **kwargs):
        path = "/members"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.ListMembersOutput"),
            **kwargs,
        )

    def AssignMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.team_id)+"/users/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.team_id = ""
        request.member_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.AssignMemberOutput"),
            **kwargs,
        )

    def UnassignMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.team_id)+"/users/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.team_id = ""
        request.member_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UnassignMemberOutput"),
            **kwargs,
        )

    def DescribeMemberUsage(self, request, **kwargs):
        path = "/usage/members"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeMemberUsageOutput"),
            **kwargs,
        )

    def UnsubscribeMember(self, request, **kwargs):
        path = "/members/"+urllib.parse.quote(request.member_id)+"/unsubscribe"

        # Cleanup URL parameters to avoid any ambiguity
        request.member_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UnsubscribeMemberOutput"),
            **kwargs,
        )

